@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * goc-pixbuf.h:
  *
@@ -32,6 +31,7 @@ struct _GocPixbuf {
 
 	double x, y, width, height, rotation;
 	GdkPixbuf *pixbuf;
+	gpointer priv;
 };
 typedef GocItemClass GocPixbufClass;
 
